{% extends "admin/base_site.html" %}
{% load i18n wpadmin_tags %}

{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; {% trans 'Password reset' %}
</div>
{% endblock %}

{% block title %}{% trans 'Password reset complete' %} | {% wpadmin_render_custom_title %}{% endblock %}

{% block content %}

<h1>{% trans 'Password reset complete' %}</h1>

<p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>

<p><a href="{{ login_url }}">{% trans 'Log in' %}</a></p>

{% endblock %}
