{% extends "admin/base_site.html" %}
{% load i18n static wpadmin_tags %}
{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />{% endblock %}
{% block userlinks %}{% url 'django-admindocs-docroot' as docsroot %}{% if docsroot %}<a href="{{ docsroot }}">{% trans 'Documentation' %}</a> / {% endif %} {% trans 'Change password' %} / <a href="{% url 'admin:logout' %}">{% trans 'Log out' %}</a>{% endblock %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; {% trans 'Password change' %}
</div>
{% endblock %}
{% block title %}{% trans 'Password change' %} | {% wpadmin_render_custom_title %}{% endblock %}

{% block content %}<div id="content-main">

<form action="" method="post">{% csrf_token %}
<div>
<h1>{% trans 'Password change' %}</h1>

<p>{% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>

{% if form.errors %}
    <p class="errornote">
    {% if form.errors.items|length == 1 %}{% trans "Please correct the error below." %}{% else %}{% trans "Please correct the errors below." %}{% endif %}
    </p>
{% endif %}

<fieldset class="module aligned wide">

<div class="form-row {% if form.old_password.errors %}errors{% endif %}">
    <div>
        {{ form.old_password.errors }}
        <label for="id_old_password" class="required">{% trans 'Old password' %}:</label>{{ form.old_password }}
    </div>
</div>

<div class="form-row {% if form.new_password1.errors %}errors{% endif %}">
    <div>
        {{ form.new_password1.errors }}
        <label for="id_new_password1" class="required">{% trans 'New password' %}:</label>{{ form.new_password1 }}
    </div>
</div>

<div class="form-row {% if form.new_password2.errors %}errors{% endif %}">
    <div>
        {{ form.new_password2.errors }}
        <label for="id_new_password2" class="required">{% trans 'Password (again)' %}:</label>{{ form.new_password2 }}
    </div>
</div>

</fieldset>

<div id="bottombar">
    <button type="submit" title="{% trans 'Change my password' %}" class="default"><i class="fa fa-lg fa-floppy-o"></i> <span class="text">{% trans 'Change my password' %}</span></button>
</div>

<script type="text/javascript">document.getElementById("id_old_password").focus();</script>
</div>
</form></div>

{% endblock %}
